# Generated by Django 5.1 on 2024-07-31 11:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0030_rename_publicsource_source_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="cellmarker",
            name="name",
            field=models.CharField(db_index=True, max_length=64),
        ),
        migrations.AlterUniqueTogether(
            name="cellmarker",
            unique_together={("name", "organism")},
        ),
    ]
